pub struct UlpWakeupSource { /* private fields */ }Expand description
ULP wakeup source
Wake up from ULP software interrupt, and/or ULP-RISCV Trap condition. Both of these triggers are enabled by default. This source will clear any outstanding software interrupts prior to entering sleep, by default.
S2 supports the following triggers (Refer to ESP32-S2 Technical Reference Manual, Table 9.4-3. Wakeup Source)
- ULP-FSM software interrupt (unsure if this ALSO supports ULP-RISCV software interrupt)
- ULP-RISCV Trap
S3 supports the following triggers (Refer to ESP32-S3 Technical Reference Manual, Table 10.4-3. Wakeup Source)
- ULP-FSM software interrupt and ULP-RISCV software interrupt
- ULP-RISCV Trap
This wakeup source can be used to wake up from both light and deep sleep.
Implementations
Sourceimpl UlpWakeupSource
impl UlpWakeupSource
Sourcepub fn set_wake_on_interrupt(self, value: bool) -> Self
pub fn set_wake_on_interrupt(self, value: bool) -> Self
Enable wakeup triggered by software interrupt from ULP-FSM or ULP-RISCV
Sourcepub fn set_wake_on_trap(self, value: bool) -> Self
pub fn set_wake_on_trap(self, value: bool) -> Self
Enable wakeup triggered by ULP-RISCV Trap
Sourcepub fn set_clear_interrupts_on_sleep(self, value: bool) -> Self
pub fn set_clear_interrupts_on_sleep(self, value: bool) -> Self
Enable clearing of latched wake-up interrupts prior to entering sleep
Sourcepub fn clear_interrupts(&self)
pub fn clear_interrupts(&self)
Clears the wake-up interrupts